# Demo multiply
A small demo library.

### Installation
```
pip install demo-multiply
```

### Get started
How to multiply one number by another with this lib:

```Python
from demo_multiply import Multiplication

# Instantiate a Multiplication object
multiplication = Multiplication(2)

# Call the multiply method
result = multiplication.multiply(5)
```